@@ -1,6 +1,6 @@
 #!/bin/bash
 
-DESKTOP_CODE=$(cat $HOME/.desktop-session/desktop-code$DISPLAY);
+DESKTOP_CODE=$(cat $HOME/.desktop-session/desktop-code.0);
 SESSION_FILE="$HOME/.desktop-session/session.conf";
 case $DESKTOP_CODE in
     rox-*)
